@@ -37,6 +37,11 @@
 
 #include "dahdi_tools_version.h"
 
+static inline int is_digital_span(struct dahdi_spaninfo *s)
+{
+	return (s->linecompat > 0);
+}
+
 int main(int argc, char *argv[])
 {
 	int ctl;
@@ -88,8 +93,17 @@ int main(int argc, char *argv[])
 				strcat(alarms,"BLU/");
 			if (s.alarms & DAHDI_ALARM_YELLOW)
 				strcat(alarms, "YEL/");
-			if (s.alarms & DAHDI_ALARM_RED)
+			if (s.alarms & DAHDI_ALARM_RED) {
 				strcat(alarms, "RED/");
+
+/* Extended alarm feature test. Allows compilation with
+ * versions of dahdi-linux prior to 2.4
+ */
+#ifdef DAHDI_ALARM_LFA
+				if (s.alarms & DAHDI_ALARM_LFA)
+					strcat(alarms, "LFA/");
+#endif /* ifdef DAHDI_ALARM_LFA */
+			}
 			if (s.alarms & DAHDI_ALARM_LOOPBACK)
 				strcat(alarms,"LB/");
 			if (s.alarms & DAHDI_ALARM_RECOVER)
@@ -103,10 +117,35 @@ int main(int argc, char *argv[])
 				alarms[strlen(alarms)-1]='\0';
 			}
 		} else {
-			if (s.numchans)
-				strcpy(alarms, "OK");
-			else
+			if (s.numchans) {
+#ifdef DAHDI_ALARM_LFA
+				/* If we continuously receive framing errors
+				 * but our span is still in service, and we
+				 * are configured for E1 & crc4. We've lost
+				 * crc4-multiframe alignment
+				 */
+				if ((s.linecompat & DAHDI_CONFIG_CRC4) &&
+				    (s.fecount > 0)) {
+					struct dahdi_spaninfo t;
+					memset(&t, 0, sizeof(t));
+					t.spanno = x;
+					sleep(1);
+					if (ioctl(ctl, DAHDI_SPANSTAT, &t))
+						continue;
+
+					/* Test fecount at two separate time
+					 * intervals, if they differ, throw LMFA
+					 */
+					if ((t.fecount > s.fecount) &&
+						!t.alarms) {
+						strcat(alarms, "LMFA/");
+					}
+				}
+#endif /* ifdef DAHDI_ALARM_LFA */
+				strcat(alarms, "OK");
+			} else {
 				strcpy(alarms, "UNCONFIGURED");
+			}
 		}
 
 		fprintf(stdout, "[%d]\n", x);
@@ -128,7 +167,7 @@ int main(int argc, char *argv[])
 			continue;
 		}
 
-		if (params.sigcap & (__DAHDI_SIG_DACS |  DAHDI_SIG_CAS)) {
+		if (is_digital_span(&s)) {
 			/* this is a digital span */
 			fprintf(stdout, "type=digital-%s\n", s.spantype);
 			fprintf(stdout, "syncsrc=%d\n", s.syncsrc);
@@ -157,7 +196,8 @@ int main(int argc, char *argv[])
 			if (s.lineconfig & DAHDI_CONFIG_ESF) fprintf(stdout, "ESF");
 			else if (s.lineconfig & DAHDI_CONFIG_D4) fprintf(stdout, "D4");
 			else if (s.lineconfig & DAHDI_CONFIG_CCS) fprintf(stdout, "CCS");
-			else if (s.lineconfig & DAHDI_CONFIG_CRC4) fprintf(stdout, "/CRC4");
+			else fprintf(stdout, "CAS");
+			if (s.lineconfig & DAHDI_CONFIG_CRC4) fprintf(stdout, "/CRC4");
 			fprintf(stdout, "\n");
 		} else {
 			/* this is an analog span */
