@@ -32,10 +32,10 @@
 #include <arpa/inet.h>
 #include <ctype.h>
 #include "mpp.h"
-#include "mpp_funcs.h"
-#include "debug.h"
+#include "mpptalk.h"
+#include <debug.h>
 
-static const char rcsid[] = "$Id: astribank_allow.c 7908 2010-01-13 16:26:15Z tzafrir $";
+static const char rcsid[] = "$Id: astribank_allow.c 10032 2011-07-10 16:25:18Z tzafrir $";
 
 #define	DBG_MASK	0x80
 
@@ -106,6 +106,7 @@ static int write_to_file(struct eeprom_table *eeprom_table, struct capabilities
 	fprintf(f, "Capabilities.Port.FXO: %d\n", caps->ports_fxo);
 	fprintf(f, "Capabilities.Port.BRI: %d\n", caps->ports_bri);
 	fprintf(f, "Capabilities.Port.PRI: %d\n", caps->ports_pri);
+	fprintf(f, "Capabilities.Port.ECHO: %d\n", caps->ports_echo);
 	fprintf(f, "Capabilities.Twinstar: %d\n", CAP_EXTRA_TWINSTAR(caps));
 	fprintf(f, "Data:\n");
 	bin_to_file(eeprom_table, sizeof(*eeprom_table), f);
@@ -327,7 +328,7 @@ int main(int argc, char *argv[])
 		usage();
 	}
 	DBG("Startup %s\n", devpath);
-	if((astribank = mpp_init(devpath)) == NULL) {
+	if((astribank = mpp_init(devpath, 1)) == NULL) {
 		ERR("Failed initializing MPP\n");
 		return 1;
 	}
