@@ -20,6 +20,8 @@
  *
  */
 
+#include <unistd.h>
+#include <stdlib.h>
 #include <stdio.h>
 #include <assert.h>
 #include <string.h>
@@ -30,7 +32,7 @@
 #include <usb.h>
 #include "hexfile.h"
 
-static const char rcsid[] = "$Id: fpga_load.c 7471 2009-11-04 16:36:21Z tzafrir $";
+static const char rcsid[] = "$Id: fpga_load.c 7908 2010-01-13 16:26:15Z tzafrir $";
 
 #define	ERR(fmt, arg...) do { \
 				if(verbose >= LOG_ERR) \
