@@ -5,12 +5,11 @@ package Dahdi::Span;
 # This program is free software; you can redistribute and/or
 # modify it under the same terms as Perl itself.
 #
-# $Id: Span.pm 7473 2009-11-04 17:25:21Z tzafrir $
+# $Id: Span.pm 10186 2011-09-07 07:10:28Z tzafrir $
 #
 use strict;
 use Dahdi::Utils;
 use Dahdi::Chans;
-use Dahdi::Xpp::Xpd;
 
 =head1 NAME
 
@@ -113,8 +112,6 @@ actually set in the module as capital-letter propeties. To look at e.g.
 
 =cut
 
-my $proc_base = "/proc/dahdi";
-
 sub chans($) {
 	my $span = shift;
 	return @{$span->{CHANS}};
@@ -135,6 +132,7 @@ my @bri_strings = (
 		'octoBRI \[(NT|TE)\] ',
 		'HFC-S PCI A ISDN.* \[(NT|TE)\] ',
 		'(B4XXP) \(PCI\) Card', # Does not expose NT/TE type
+		'(WCBRI)', # has selectable NT/TE modes via dahdi_cfg
 		);
 
 my @pri_strings = (
@@ -150,8 +148,14 @@ my @pri_strings = (
 		'R[24]T1 \(PCI\) Card',            # rxt1
 		'Rhino R1T1 (E1)/PRA Card',        # r1t1
 		'Rhino R1T1 (T1)/PRI Card',        # r1t1
+		'WP(E1|T1)/.* "wanpipe',           # Sangoma E1/T1
 		);
 
+my @soft_term_type_strings = (
+		'Xorcom XPD.*: (E1|T1)',           # Astribank PRI
+		'(WCBRI)', # has selectable NT/TE modes via dahdi_cfg
+);
+
 our $DAHDI_BRI_NET = 'bri_net';
 our $DAHDI_BRI_CPE = 'bri_cpe';
 
@@ -175,17 +179,13 @@ sub init_proto($$) {
 
 sub new($$) {
 	my $pack = shift or die "Wasn't called as a class method\n";
-	my $num = shift or die "Missing a span number parameter\n";
+	my $proc_file = shift or die "Missing a proc file parameter\n";
+	$proc_file =~ m{[^/]*/(\d+)$};
+	my $num = $1 or die " Invalid span file name: $proc_file\n";
 	my $self = { NUM => $num };
 	bless $self, $pack;
 	$self->{TYPE} = "UNKNOWN";
-	my @xpds = Dahdi::Xpp::Xpd::xpds_by_spanno;
-	my $xpd = $xpds[$num];
-	if(defined $xpd) {
-		die "Spanno mismatch: $xpd->spanno, $num" unless $xpd->spanno == $num;
-		$self->{XPD} = $xpd;
-	}
-	open(F, "$proc_base/$num") or die "Failed to open '$proc_base/$num\n";
+	open(F, "$proc_file") or die "Failed to open '$proc_file\n";
 	my $head = <F>;
 	chomp $head;
 	$self->{IS_DIGITAL} = 0;
@@ -194,13 +194,14 @@ sub new($$) {
 	foreach my $cardtype (@bri_strings) {
 		if($head =~ m/$cardtype/) {
 			my $termtype = $1;
-			$termtype = 'TE' if ( $1 eq 'B4XXP' );
+			$termtype = 'TE' if ( $1 eq 'B4XXP' or $1 eq 'WCBRI' );
 			$self->{IS_DIGITAL} = 1;
 			$self->{IS_BRI} = 1;
 			$self->{TERMTYPE} = $termtype;
 			$self->{TYPE} = "BRI_$termtype";
 			$self->{DCHAN_IDX} = 2;
 			$self->{BCHAN_LIST} = [ 0, 1 ];
+			$self->init_proto('BRI');
 			last;
 		}
 	}
@@ -222,13 +223,21 @@ sub new($$) {
 			last;
 		}
 	}
+	$self->{IS_SOFT_TERM_TYPE} = 0;
+	foreach my $cardtype (@soft_term_type_strings) {
+		if($head =~ m/$cardtype/) {
+			$self->{IS_SOFT_TERM_TYPE} = 1;
+			last;
+		}
+	}
 	($self->{NAME}, $self->{DESCRIPTION}) = (split(/\s+/, $head, 4))[2, 3];
 	$self->{IS_DAHDI_SYNC_MASTER} =
 		($self->{DESCRIPTION} =~ /\(MASTER\)/) ? 1 : 0;
 	$self->{CHANS} = [];
 	my @channels;
 	my $index = 0;
-	while(<F>) {
+	my @channel_lines = <F>;
+	foreach (@channel_lines) {
 		chomp;
 		s/^\s*//;
 		s/\s*$//;
@@ -259,6 +268,8 @@ sub new($$) {
 	$self->{CHANS} = \@channels;
 	$self->{YELLOW} = undef;
 	$self->{CRC4} = undef;
+	$self->{SOFTNTTE} = undef;
+	$self->{TERMINATION} = undef;
 	if($self->is_bri()) {
 		$self->{CODING} = 'ami';
 		$self->{DCHAN} = ($self->chans())[$self->{DCHAN_IDX}];
@@ -266,7 +277,11 @@ sub new($$) {
 		# Infer some info from channel name:
 		my $first_chan = ($self->chans())[0] || die "$0: No channels in span #$num\n";
 		my $chan_fqn = $first_chan->fqn();
-		if($chan_fqn =~ m(ZTHFC.*/|ztqoz.*/|XPP_BRI_.*|B4/.*)) {		# BRI
+		if($chan_fqn =~ m(ZTHFC.*/|ztqoz.*/|XPP_BRI_.*|B4/.*|WCBRI/.*)) {		# BRI
+			if($chan_fqn =~ m(WCBRI/.*)) {		# make sure to set termination resistors on hybrid cards
+				$self->{TERMINATION} = 'term';
+				$self->{SOFTNTTE} = 'te';
+			}
 			$self->{FRAMING} = 'ccs';
 			$self->{SWITCHTYPE} = 'euroisdn';
 			$self->{SIGNALLING} = ($self->{TERMTYPE} eq 'NT') ? $DAHDI_BRI_NET : $DAHDI_BRI_CPE ;
@@ -304,7 +319,11 @@ sub set_termtype($$) {
 	my $span = shift || die;
 	my $termtype = shift || die;
 	$span->{TERMTYPE} = $termtype;
-	$span->{SIGNALLING} = ($termtype eq 'NT') ? $DAHDI_PRI_NET : $DAHDI_PRI_CPE ;
+	if ($span->is_pri) {
+		$span->{SIGNALLING} = ($termtype eq 'NT') ? $DAHDI_PRI_NET : $DAHDI_PRI_CPE ;
+	} elsif ($span->is_bri) {
+		$span->{SIGNALLING} = ($termtype eq 'NT') ? $DAHDI_BRI_NET : $DAHDI_BRI_CPE ;
+	}
 	$span->{TYPE} = $span->proto . "_$termtype";
 }
 
@@ -312,6 +331,7 @@ sub pri_set_fromconfig($$) {
 	my $span = shift || die;
 	my $genconf = shift || die;
 	my $name = $span->name;
+	return unless $span->is_soft_term_type;
 #	if(defined $termtype) {
 #		die "Termtype for $name already defined as $termtype\n";
 #	}
@@ -322,10 +342,17 @@ sub pri_set_fromconfig($$) {
 	}
 	push(@pri_specs , 'SPAN/* TE');		# Default
 	my @patlist = ( "SPAN/" . $span->num );
-	my ($xbus_name, $xpd_name) = ($name =~ m|(XBUS-\d+)/(XPD-\d+)|);
-	if(defined $xbus_name) {
+	my $xpd = Dahdi::Xpp::xpd_of_span($span);
+	if(defined $xpd) {
+		my $xbus = $xpd->xbus;
+		my $xbus_name = $xbus->name;
+		my $xpd_name = "XPD-" . $xpd->id;
+		my $label = $xbus->label;
+		my $connector = $xbus->connector;
+		#print "DEBUG: '$xbus_name/$xpd_name' LABEL='$label' CONNECTOR='$connector'\n";
 		push(@patlist, "NUM/$xbus_name/$xpd_name");
-#		push(@patlist, "CONNECTOR/$ENV{XBUS_CONNECTOR}/$xpd_name");
+		push(@patlist, "LABEL/$label/$xpd_name");
+		push(@patlist, "CONNECTOR/$connector/$xpd_name");
 	}
 	#print STDERR "PATLIST=@patlist\n";
 	my $match_termtype;
@@ -341,8 +368,8 @@ SPEC:
 		#print STDERR "match: $match\n";
 		foreach my $pattern (@patlist) {
 			#print STDERR "testmatch: $pattern =~ $match\n";
-			if($pattern =~ $match) {
-				#print STDERR "$xpd_name: MATCH '$pattern' ~ '$match' termtype=$termtype\n";
+			if($pattern =~ /^$match$/) {
+				#print STDERR "MATCH '$pattern' ~ '$match' termtype=$termtype\n";
 				$match_termtype = $termtype;
 				last SPEC;
 			}
